#ifndef MSP_AL_JUKEBOX_H_
#define MSP_AL_JUKEBOX_H_

#include <list>
#include <string>
#include <sigc++/signal.h>
#include "source.h"
#include "streamer.h"

namespace Msp {
namespace AL {

class SoundDecoder;

class Jukebox
{
public:
	sigc::signal<void, const std::string &> signal_track_changed;

private:
	Source source;
	Streamer streamer;
	SoundDecoder *decoder;
	std::list<std::string> tracks;
	std::list<std::string>::iterator current_track;
	bool shuffle;

public:
	Jukebox();
	~Jukebox();

	Source &get_source() { return source; }
	void add_track(const std::string &);
	void remove_track(const std::string &);
	void clear_tracks();
	const std::string &get_current_track() const;
	void set_shuffle(bool);

	void play();
	void next();
	void previous();
	void stop();
	void tick();
};

} // namespace AL
} // namespace Msp

#endif
